Parametric Objects
------------------

The following functions can be used to create parametric surfaces.  To
see what these functions create, check out the example: :ref:`ref_parametric_example`.

.. autofunction:: pyvista.ParametricBohemianDome
.. autofunction:: pyvista.ParametricBour
.. autofunction:: pyvista.ParametricBoy
.. autofunction:: pyvista.ParametricDini
.. autofunction:: pyvista.ParametricEllipsoid
.. autofunction:: pyvista.ParametricEnneper
.. autofunction:: pyvista.ParametricFigure8Klein
.. autofunction:: pyvista.ParametricHenneberg
.. autofunction:: pyvista.ParametricKlein
.. autofunction:: pyvista.ParametricKuen
.. autofunction:: pyvista.ParametricMobius
.. autofunction:: pyvista.ParametricPluckerConoid
.. autofunction:: pyvista.ParametricPseudosphere
.. autofunction:: pyvista.ParametricRandomHills
.. autofunction:: pyvista.ParametricRoman
.. autofunction:: pyvista.ParametricSuperEllipsoid
.. autofunction:: pyvista.ParametricSuperToroid
.. autofunction:: pyvista.ParametricTorus

These functions support building parametric surfaces:

.. autofunction:: pyvista.parametric_keywords
.. autofunction:: pyvista.surface_from_para
